#!/usr/bin/env bash

test -n "${CSPP_GEO_GRB_HOME}" || echo "CSPP_GEO_GRB_HOME is not set. Please set this environment variable to the install location of CSPP Geo GRB."

test -n "${CSPP_GEO_RTCSPP_HOME}" || echo "CSPP_GEO_RTCSPP_HOME= is not set. Please source grb_env.sh to initialize your local environment."

unset LD_LIBRARY_PATH

# make sure we are using the supplied JRE
export JAVA_HOME=$CSPP_GEO_GRB_HOME/runtime/jre1.8.0_144
export PATH=$JAVA_HOME/bin:$PATH

# set the class path for all java executables
CLASSPATH=$CSPP_GEO_RTCSPP_HOME/src
CLASSPATH=$CLASSPATH:$CSPP_GEO_RTCSPP_HOME/lib/nsls.jar
CLASSPATH=$CLASSPATH:.
export CLASSPATH

if [ -n "$CSPP_GEO_RTCSPP_OUT" ]; then
  mkdir -p $CSPP_GEO_RTCSPP_OUT
fi

if [ -n "$CSPP_GEO_RTCSPP_PID" ]; then
  mkdir -p $CSPP_GEO_RTCSPP_PID
fi

if [ -n "$CSPP_GEO_RTCSPP_LOG" ]; then
  mkdir -p $CSPP_GEO_RTCSPP_LOG
fi

# Check available UDP receive buffer space against what we want
# Amount we recommend: 16 GB which gives us about 4 seconds at 31 Mb/s
# Actual amount requested is specified in grb-ingestor.conf
RECOMMENDED_UDP_BUF_SIZE=16777216

# Get the max UDP receive buffer size
udpsiz=$(cat /proc/sys/net/core/rmem_max)

# Test against what we want, warn if too low
if [[ $udpsiz -lt RECOMMENDED_UDP_BUF_SIZE ]]; then
  echo ""
  echo "WARNING: the maximum UDP buffer size on this machine is $udpsiz"
  echo "This is less than the recommended size of 16777216 (16 MB)."
  echo "RT-CSPP will be started, but your system may experience some data loss."
  echo ""
fi

# start the ingestor service wrapper with the appropriate argument
$CSPP_GEO_RTCSPP_HOME/jsw/bin/grb-ingestor.sh $1
ingstat=$?

# check exit code - if 1, there was already an ingestor running
if [[ $ingstat -eq 1 ]] ; then
   exit $ingstat
fi

# do a status call only after 'start', to show successful startup
if [ ! -z "$1" ] && [ $1 == "start" ]; then
  echo "Please wait a few moments while we ensure successful startup..."
  sleep 6
  $CSPP_GEO_RTCSPP_HOME/jsw/bin/grb-ingestor.sh status
fi
